@@ -110,15 +110,17 @@ MainWindow::MainWindow(MainWindow *pParent) :
     if ( !m_pParent ) {
         setWidget();
         visitUrl("http://www.crochik.com/macuco");
+
     } else {
+
         m_isUsingGraphicsView = m_pParent->m_isUsingGraphicsView;
         setWidget();
     }
 }
 
-MainWindow::~MainWindow()
-{
-    qDebug() << "MainWindow::~MainWindow";
+MainWindow::~MainWindow() {
+    qDebug() << "~MainWindow";
+
     if ( m_pParent ) {
         qDebug() << ">> not top most";
         m_pBookmarks = NULL;
@@ -196,7 +198,7 @@ void MainWindow::setWidget() {
         m_pGWebView->setPage(&m_webPage);
         setCentralWidget(m_pGraphicsView);
 
-        if ( !m_currentUrl.isEmpty() ) reload();
+        if ( !m_pParent ) reload();
         return;
     }
 
@@ -329,8 +331,7 @@ void MainWindow::showLoading() {
 #endif
 }
 
-void MainWindow::changeUrl(QUrl url)
-{
+void MainWindow::changeUrl(QUrl url) {
     /*
     QIcon icon = m_webPage.settings()->iconForUrl(url);
     qDebug() << icon.isNull();
@@ -343,17 +344,16 @@ void MainWindow::changeUrl(QUrl url)
 #endif
 }
 
-void MainWindow::visitUrl(QString url)
-{
+void MainWindow::visitUrl(QString url) {
     if ( url.isNull() || url.isEmpty() ) return;
+
     if ( m_isUsingGraphicsView )
         m_pGWebView->load(QUrl::fromUserInput(url));
     else
         m_pWebView->load(QUrl::fromUserInput(url));
 }
 
-void MainWindow::reload()
-{
+void MainWindow::reload() {
     if ( m_isUsingGraphicsView )
         m_pGWebView->load(m_currentUrl);
     else
@@ -399,9 +399,26 @@ void MainWindow::closeEvent(QCloseEvent *event)
 #endif
 
     if ( !m_pParent ) {
+        if (!m_children.isEmpty()) {
+            if ( QMessageBox::question(this, "Close Application",
+                "Closing this window will close all other macuco windows.\n"
+                "Would you like to continue?",
+                QMessageBox::Yes, QMessageBox::No
+                )!=QMessageBox::Yes
+            ) {
+                event->ignore();
+                return;
+            }
+        }
+
         // top most
         saveSettings();
         m_webPage.saveCookies();
+
+    } else {
+        qDebug() << "remove from parent list and schedule for deletion";
+        m_pParent->m_children.removeOne(this);
+        deleteLater();
     }
 
     event->accept();
@@ -534,7 +551,7 @@ void MainWindow::on_actionAdd_Bookmark_triggered()
 {
     BookmarkDlg dlg(this);
     dlg.setUrl(m_currentUrl.toString());
-    dlg.setTitle(m_pGWebView->title());
+    dlg.setTitle( m_isUsingGraphicsView ? m_pGWebView->title() : m_pWebView->title() );
     dlg.removeBtt()->setVisible(false);
 
     if ( dlg.exec()!= QDialog::Accepted ) return;
@@ -673,10 +690,8 @@ void MainWindow::hideToolbar()
 #endif
 
 
-void MainWindow::on_actionUser_Agent_triggered()
-{
+void MainWindow::on_actionUser_Agent_triggered() {
     setUserAgent(!m_webPage.isIphoneUserAgent());
-    // reload();
 }
 
 void MainWindow::setUserAgent(bool iphone/*=true*/) {
@@ -706,7 +721,6 @@ void MainWindow::unsupportedContent(QNetworkReply* pReply) {
 }
 
 void MainWindow::downloadRequested (const QNetworkRequest& request) {
-    qDebug() << "downloadRequested: "; // << request;
 }
 
 void MainWindow::finishedRequest(QNetworkReply* reply)
@@ -730,24 +744,11 @@ void MainWindow::hideLoading(bool success) {
 
     if ( !success ) {
         QString msg("<b>Loading Error</b><br/>");
-        if ( m_errors.length()>1 ) msg+=m_errors.join("<br/>"); else msg+=m_currentUrl.toString();
+        if ( m_errors.length()>0 ) msg+=m_errors.join("<br/>"); else msg+=m_currentUrl.toString();
         QMaemo5InformationBox::information(this,
             msg,
             QMaemo5InformationBox::DefaultTimeout
         );
-
-        /*
-        if ( QMessageBox::warning(
-            this,
-            "Loading Error",
-            m_errors.count()>0 ? m_errors.join("\n") : "Unspecified",
-            QMessageBox::Retry, QMessageBox::Cancel
-        )== QMessageBox::Retry )
-        {
-            // retry
-            reload();
-        }
-        */
         return;
     }
 
