@@ -5,7 +5,10 @@
 #include <QtWebKit>
 #include <QtDebug>
 
-class ViewportItem : public QGraphicsWidget, public QAbstractKineticScroller
+class ViewportItem : public QGraphicsWidget
+#ifdef Q_WS_MAEMO_5
+        , public QAbstractKineticScroller
+#endif
 {
     Q_OBJECT
 
